/*******************************************************************************
 * Copyright 2012 pw999
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.oqt.maven;

import static org.fest.assertions.Assertions.assertThat;

import java.sql.SQLException;

import net.sf.oqt.core.CoreFactory;
import net.sf.oqt.jpa.failentities.TableFail;
import net.sf.oqt.jpa.testentities.subpackage.RefA;
import net.sf.oqt.maven.QueryTranslatorValidateMojo;

import org.apache.maven.monitor.logging.DefaultLog;
import org.apache.maven.plugin.MojoFailureException;
import org.codehaus.plexus.logging.console.ConsoleLogger;
import org.fest.assertions.Fail;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;



public class QueryTranslatorValidateMojoTest {

	private QueryTranslatorValidateMojo mojo = null;
	
	@Before
	public void setUp() throws Exception {
		mojo = new QueryTranslatorValidateMojo();
		mojo.setLog(new DefaultLog(new ConsoleLogger(4, "junit")));
		mojo.getPackageNames().clear();
	}
	
	@After
	public void tearDown() throws SQLException {
		CoreFactory.shutdown();
	}

	@Test
	public void testExecuteSuccess() throws Exception {
		mojo.getPackageNames().add(RefA.class.getPackage().getName());
		mojo.execute();
	}
	
	@Test
	public void testExecuteError() throws Exception {
		mojo.getPackageNames().add(TableFail.class.getPackage().getName());
		try {
			mojo.execute();
			Fail.fail("Expected an exception due to invalid JPQL queries");
		} catch (MojoFailureException e) {
			assertThat(e.getMessage()).isEqualTo("Some JPQL queries could not be validated");
		}
	}

}
